@@ -1,7 +1,8 @@
 package org.gcube.portlets.user.tdcolumnoperation.client;
 
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnDataTypeElement;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnTypeCodeElement;
+
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnDataTypeElement;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnTypeCodeElement;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
@@ -177,7 +178,7 @@ public class SplitColumnPanel extends FramedPanel implements
 		} catch (Exception e) {
 			GWT.log("Error:" + e.getCause());
 		}
-		comboColumnData = new LoadComboColumnData(trId, eventBus, columnName,
+		comboColumnData = new LoadComboColumnDataForSplit(trId, eventBus, columnName,
 				false);
 		initForm();
 		forceLayout();
